@@ -38,7 +38,9 @@ def format(task=None, lister=False):
         'Workflow name',
         'Execution ID',
         'State',
-        'State info'
+        'State info',
+        'Created at',
+        'Updated at'
     )
 
     if task:
@@ -51,7 +53,9 @@ def format(task=None, lister=False):
             task.workflow_name,
             task.workflow_execution_id,
             task.state,
-            state_info
+            state_info,
+            task.created_at,
+            task.updated_at or '<none>'
         )
     else:
         data = (tuple('<none>' for _ in range(len(columns))),)
@@ -68,15 +72,42 @@ class List(base.MistralLister):
         parser.add_argument(
             'workflow_execution',
             nargs='?',
-            help='Workflow execution ID associated with list of Tasks.')
+            help='Workflow execution ID associated with list of Tasks.'
+        )
+        parser.add_argument(
+            '--filter',
+            dest='filters',
+            action='append',
+            help='Filters. Can be repeated.'
+        )
+        parser.add_argument(
+            '--limit',
+            type=int,
+            help='Maximum number of tasks to return in a single result. '
+                 'limit is set to %s by default. Use --limit -1 to fetch the '
+                 'full result set.' % base.DEFAULT_LIMIT,
+            nargs='?'
+        )
+
         return parser
 
     def _get_format_function(self):
         return format_list
 
     def _get_resources(self, parsed_args):
+        if parsed_args.limit is None:
+            parsed_args.limit = base.DEFAULT_LIMIT
+            LOG.info("limit is set to %s by default. Set "
+                     "the limit explicitly using \'--limit\', if required. "
+                     "Use \'--limit\' -1 to fetch the full result set.",
+                     base.DEFAULT_LIMIT)
         mistral_client = self.app.client_manager.workflow_engine
-        return mistral_client.tasks.list(parsed_args.workflow_execution)
+
+        return mistral_client.tasks.list(
+            parsed_args.workflow_execution,
+            limit=parsed_args.limit,
+            **base.get_filters(parsed_args)
+        )
 
 
 class Get(command.ShowOne):
